==> boo_0.5.6.1701.orig.tar.gz: boo-0.5.6.1701/src/Boo.Lang.Compiler/TypeSystem/InternalEvent.cs <==
#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

namespace Boo.Lang.Compiler.TypeSystem
{
	using System;
	using Boo.Lang.Compiler.Ast;
	
	public class InternalEvent : IEvent, IInternalEntity
	{	
		Event _event;
		
		InternalField _backingField;
		
		public InternalEvent(TypeSystemServices tagManager, Event event_)
		{
			_event = event_;
		}
		
		public IType DeclaringType
		{
			get
			{
				return (IType)TypeSystemServices.GetEntity(_event.DeclaringType);
			}
		}
		
		public IMethod GetAddMethod()
		{
			return (IMethod)TypeSystemServices.GetEntity(_event.Add);
		}
		
		public IMethod GetRemoveMethod()
		{
			return (IMethod)TypeSystemServices.GetEntity(_event.Remove);
		}
		
		public IMethod GetRaiseMethod()
		{
			return (IMethod)TypeSystemServices.GetEntity(_event.Raise);
		}
		
		public Event Event
		{
			get
			{
				return _event;
			}
		}
		
		public Node Node
		{
			get
			{
				return _event;
			}
		}
		
		public bool IsPublic
		{
			get
			{
				return _event.IsPublic;
			}
		}
		
		public string Name
		{
			get
			{
				return _event.Name;
			}
		}
		
		public string FullName
		{
			get
			{
				return _event.DeclaringType.FullName + "." + _event.Name;
			}
		}
		
		public EntityType EntityType
		{
			get
			{
				return EntityType.Event;
			}
		}
		
		public IType Type
		{
			get
			{
				return (IType)TypeSystemServices.GetEntity(_event.Type);
			}
		}
		
		public bool IsStatic
		{
			get
			{
				return _event.IsStatic;
			}
		}
		
		public InternalField BackingField
		{
			get
			{
				return _backingField;
			}
			
			set
			{
				_backingField = value;
			}
		}
	}
}

==> boo_0.7.0.1921.orig.tar.gz: boo-0.7.0.1921/src/Boo.Lang.Compiler/TypeSystem/InternalEvent.cs <==
#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

namespace Boo.Lang.Compiler.TypeSystem
{
	using Boo.Lang.Compiler.Ast;

	public class InternalEvent : IEvent, IInternalEntity
	{	
		Event _event;
		
		InternalField _backingField;
		
		public InternalEvent(TypeSystemServices tagManager, Event event_)
		{
			_event = event_;
		}
		
		public IType DeclaringType
		{
			get
			{
				return (IType)TypeSystemServices.GetEntity(_event.DeclaringType);
			}
		}
		
		public IMethod GetAddMethod()
		{
			return (IMethod)TypeSystemServices.GetEntity(_event.Add);
		}
		
		public IMethod GetRemoveMethod()
		{
			return (IMethod)TypeSystemServices.GetEntity(_event.Remove);
		}
		
		public IMethod GetRaiseMethod()
		{
			return (IMethod)TypeSystemServices.GetEntity(_event.Raise);
		}
		
		public Event Event
		{
			get
			{
				return _event;
			}
		}
		
		public Node Node
		{
			get
			{
				return _event;
			}
		}
		
		public bool IsPublic
		{
			get
			{
				return _event.IsPublic;
			}
		}
		
		public string Name
		{
			get
			{
				return _event.Name;
			}
		}
		
		public string FullName
		{
			get
			{
				return _event.DeclaringType.FullName + "." + _event.Name;
			}
		}
		
		public EntityType EntityType
		{
			get
			{
				return EntityType.Event;
			}
		}
		
		public IType Type
		{
			get
			{
				return (IType)TypeSystemServices.GetEntity(_event.Type);
			}
		}
		
		public bool IsStatic
		{
			get
			{
				return _event.IsStatic;
			}
		}

		public bool IsVirtual
		{
			get
			{
				return _event.IsVirtual;
			}
		}

		public bool IsAbstract
		{
			get
			{
				return _event.IsAbstract;
			}
		}

		public InternalField BackingField
		{
			get
			{
				return _backingField;
			}
			
			set
			{
				_backingField = value;
			}
		}

		public bool IsDuckTyped
		{
			get { return false; }
		}
	}
}
